@@ -37,20 +37,19 @@ devel_docs = ('translating-solfege',
                )
 
 exercises = ('chord',
-             'chord-voicing',
-             'harmonic-interval',
-             'melodic-interval',
-             'sing-interval',
-             'identify-scale',
-             'id-by-name',
+             'chordvoicing',
+             'harmonicinterval',
+             'melodicinterval',
+             'singinterval',
+             'idbyname',
              'dictation',
-             'twelve-tone',
-             'id-tone',
-             'compare-intervals',
-             'sing-chord',
+             'twelvetone',
+             'idtone',
+             'compareintervals',
+             'singchord',
              'rhythm',
-             'identify-bpm',
-             'harmonic-progression-dictation'
+             'identifybpm',
+             #'harmonic-progression-dictation'
              )
 
 msg1 = _("""Because not all documents has been
