@@ -17,7 +17,8 @@
 
 import gtk, gnome
 import gobject
-import gu, widgets
+import gu
+from specialwidgets import QuestionNameCheckButtonTable
 import soundcard, mpd, mpd.musicdisplayer
 import abstract, const, lessonfile
 import utils
@@ -181,12 +182,11 @@ class Gui(abstract.LessonbasedGui):
         self.g_select_questions_category_box, category_box= gu.hig_category_vbox(
             _("Chord types to ask"))
         self.config_box.pack_start(self.g_select_questions_category_box, True)
-        self.g_select_questions = widgets.QuestionNameCheckButtonTable(self.m_t)
+        self.g_select_questions = QuestionNameCheckButtonTable(self.m_t)
         self.g_select_questions.initialize(4, 0)
         category_box.pack_start(self.g_select_questions, False)
         self.g_select_questions.show()
 
-        self.update_gui_after_lessonfile_change()
     def update_select_question_buttons(self):
         if self.get_bool('gui/expert_mode'):
             self.g_select_questions_category_box.show()
@@ -204,7 +204,8 @@ class Gui(abstract.LessonbasedGui):
               + self.g_toptone_box.get_children():
             x.destroy()
         if self.m_t.m_P:
-            for ctype, translated_type in self.m_t.m_P.m_chord_types.iteritems():
+            for ctype in self.m_t.m_P.get_unique_cnames():
+                translated_type = self.m_t.m_P.m_chord_types[ctype]
                 b = gtk.Button(translated_type)
                 sr = b.size_request()
                 b.set_size_request(int(sr[0]*1.3), sr[1])
@@ -237,27 +238,26 @@ class Gui(abstract.LessonbasedGui):
                 b.connect('button_release_event', self.on_toptone)
                 self.g_toptone_box.pack_start(b, False)
                 b.show()
+        self.g_inversion_box.set_sensitive(True)
+        self.g_toptone_box.set_sensitive(True)
     def update_gui_after_lessonfile_change(self):
         self.g_music_displayer.clear()
-        if self.m_t.m_P:
-            self.update_select_question_buttons()
-            self.set_lesson_heading(self.m_t.m_P.header.lesson_heading)
-            self.g_new.set_sensitive(True)
-            self.g_random_transpose.set_text(str(self.m_t.m_P.header.random_transpose))
-            if not [q for q in self.m_t.m_P.m_questions if 'toptone' in q]:
-                self.g_toptone_label.hide()
-                self.g_vsep2.hide()
-            else:
-                self.g_toptone_label.show()
-                self.g_vsep2.show()
-            if not [q for q in self.m_t.m_P.m_questions if 'inversion' in q]:
-                self.g_inversion_label.hide()
-                self.g_vsep1.hide()
-            else:
-                self.g_inversion_label.show()
-                self.g_vsep1.show()
+        self.update_select_question_buttons()
+        self.set_lesson_heading(self.m_t.m_P.header.lesson_heading)
+        self.g_new.set_sensitive(True)
+        self.g_random_transpose.set_text(str(self.m_t.m_P.header.random_transpose))
+        if not [q for q in self.m_t.m_P.m_questions if 'toptone' in q]:
+            self.g_toptone_label.hide()
+            self.g_vsep2.hide()
         else:
-            self.g_new.set_sensitive(False)
+            self.g_toptone_label.show()
+            self.g_vsep2.show()
+        if not [q for q in self.m_t.m_P.m_questions if 'inversion' in q]:
+            self.g_inversion_label.hide()
+            self.g_vsep1.hide()
+        else:
+            self.g_inversion_label.show()
+            self.g_vsep1.show()
         self.g_repeat.set_sensitive(False)
         self.g_repeat_arpeggio.set_sensitive(False)
         self.g_give_up.set_sensitive(False)
@@ -461,9 +461,10 @@ class Gui(abstract.LessonbasedGui):
             self.g_win.display_question_music_error_message(
                 self.m_t.m_P._idx, self.get_string('lessonfile'), e)
     def on_start_practise(self):
+        self.update_gui_after_lessonfile_change()
         self.g_flashbar.require_size([
             _("Click 'New chord' to begin."),
-            _("XXXX, root position, toptone: 5"),
+            "XXXX, root position, toptone: 5",
         ])
         self.g_new.grab_focus()
         gobject.timeout_add(const.SHORT_WAIT, lambda self=self:
