@@ -15,26 +15,15 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-__exercise_data__ = {
-    'exercise_name': 'harmonic-progression-dictation',
-    'stock-icon': 'solfege-harmonic-progression-dictation',
-    'menupath': '/Menubar/FileMenu/MiscMenu',
-    'name': _("Harmonic _progression dictation"),
-}
-import exercise_setup
-#exercise_setup.register_exercise(__exercise_data__)
-
 import gtk, gnome
-import abstract, idbyname, const, gu, statisticsviewer, widgets
+import abstract, idbyname, const, gu, statisticsviewer
 import soundcard, mpd, mpd.musicdisplayer
 import utils
 import lessonfile
 
 class Teacher(idbyname.Teacher):
-    exercise_data = __exercise_data__
-    def __init__(self, exname, app, lesson_collection, lesson_file, config):
-        idbyname.Teacher.__init__(self, exname, app,
-            lesson_collection, lesson_file, config)
+    def __init__(self, exname, app):
+        idbyname.Teacher.__init__(self, exname, app)
     def play_question(self):
         if self.q_status == const.QSTATUS_NO:
             return
@@ -81,12 +70,6 @@ class Gui(abstract.LessonbasedGui):
         ##############
         # config_box #
         ##############
-        self.add_select_lessonfile_gui()
-        self.g_instrument_configurator \
-            = widgets.InstrumentConfigurator(self.m_exname, 3)
-        self.config_box.pack_start(self.g_instrument_configurator, False)
-        self.g_instrument_configurator.show()
-        # ------------------------------------------
         self.add_random_transpose_gui()
         self._add_auto_new_question_gui(self.config_box)
         # ----------------------------------------------
@@ -97,7 +80,6 @@ class Gui(abstract.LessonbasedGui):
         self.setup_statisticsviewer(statisticsviewer.StatisticsViewer,
                                    _("Harmonic progression dictation"))
 
-        self.update_gui_after_lessonfile_change()
     def guess_answer(self, widget=None):
         if self.m_t.q_status == const.QSTATUS_NO:
             return
@@ -162,6 +144,7 @@ class Gui(abstract.LessonbasedGui):
         self.g_flashbar.push(self.m_t.m_P.get_cname())
         self.show_answer()
     def on_start_practise(self):
+        self.update_gui_after_lessonfile_change()
         self.g_guess_answer.grab_default()
         self.g_new.grab_focus()
     def on_end_practise(self):
@@ -173,18 +156,9 @@ class Gui(abstract.LessonbasedGui):
         self.m_t.end_practise()
     def update_gui_after_lessonfile_change(self):
         self.g_music_displayer.clear(2)
-        if self.m_t.m_P:
-            self.g_random_transpose.set_text(str(self.m_t.m_P.header.random_transpose))
-            self.g_new.set_sensitive(True)
-        else:
-            self.g_new.set_sensitive(False)
+        self.g_random_transpose.set_text(str(self.m_t.m_P.header.random_transpose))
+        self.g_new.set_sensitive(True)
         self.g_repeat.set_sensitive(False)
         self.g_guess_answer.set_sensitive(False)
         self.g_play_tonic.set_sensitive(False)
         self.g_show.set_sensitive(False)
-        self.m_t.m_statistics.lessonfile_changed(
-                     self.get_string('lessoncollection'),
-                     self.get_string('lessonfile'))
-        self.g_statview.m_descriptive_paragraph = \
-         _("Statistics for the lesson file '%s'") % self.get_string('lessonfile')
-        self.g_win.set_title("Solfege - " + self.get_pretty_name())
