@@ -15,10 +15,14 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+"""
+Modules that have translated messages need to import this module
+to make pydoc work.
+"""
 import gettext
 import locale
 import os
-import configureoutput
+import sys
 
 def _i(s):
     """
@@ -30,9 +34,9 @@ def _i(s):
     """
     ns = _(s)
     if ns == s:
-        return s.split('|')[-1]
+        return "%s" %(s.split('|')[-1])
     else:
-        return ns
+        return "%s" % ns
 
 def langs():
     ret = []
@@ -55,11 +59,12 @@ def langs():
     return retval
 
 def setup(prefix):
+    if sys.platform == 'win32':
+        if 'LANGUAGE' not in os.environ:
+            s = locale.getdefaultlocale()[0]
+            if '_' in s:
+                s = s.split("_")[1]
+            os.environ['LANGUAGE'] = s
     gettext.install('solfege', os.path.join(prefix, 'share', 'locale'), unicode=1)
     __builtins__['_i'] = _i
 
-def setup_srcdir():
-    gettext.install('solfege', 'share/locale', unicode=1)
-    __builtins__['_i'] = _i
-
-
