@@ -267,12 +267,20 @@ _("""You have to select some tones practise. Do this on the config page by setti
         ])
         if not runtime.has_gnome_canvas():
             return # this exercise don't work without GnomeCanvas
-        for n in ('c', 'cis', 'd', 'dis', 'e', 'f', 'fis', 'g', 'gis', 'a',
-                  'ais', 'b'):
-            if self.m_t.m_P.header.__getattr__('%s_weight' % n):
-                self.set_float('%s_weight' % n, float(self.m_t.m_P.header.__getattr__('%s_weight' % n)))
+        if 'white_keys_weight' in self.m_t.m_P.header:
+            if type(self.m_t.m_P.header.white_keys_weight) == list \
+                    and len(self.m_t.m_P.header.white_keys_weight) == 7:
+                for idx, n in enumerate(('c', 'd', 'e', 'f', 'g', 'a', 'b')):
+                    self.set_float('%s_weight' % n, self.m_t.m_P.header.white_keys_weight[idx])
             else:
-                self.set_float('%s_weight' % n, 1.0)
+                print "white_keys_weight had wrong type"
+        if 'black_keys_weight' in self.m_t.m_P.header:
+            if type(self.m_t.m_P.header.black_keys_weight) == list \
+                    and len(self.m_t.m_P.header.black_keys_weight) == 5:
+                for idx, n in enumerate(('cis', 'dis', 'fis', 'gis', 'ais')):
+                    self.set_float('%s_weight' % n, self.m_t.m_P.header.black_keys_weight[idx])
+            else:
+                print "black_keys_weight had wrong type"
         if self.get_bool('gui/expert_mode'):
             self.g_config_elems.show()
         else:
