@@ -2,6 +2,13 @@
 import os
 import signal
 
+class RunExternalFailed(Exception):
+    def __init__(self, v):
+        self.v = v
+    def __str__(self):
+        return "\nRunning external program failed.\nPlease check your setup.\nThe command that failed was: '%s'" % (" ".join(self.v[1:]))
+
+
 __all__ = ['run_external_program']
 __child_pid = None
 def run_external_program(cmdstring, wdir, argument):
