@@ -3,12 +3,9 @@
 import pygtk
 pygtk.require("2.0")
 import sys, os
-if __name__ == "__main__":
-    import sys
-    sys.path.append(".")
-    sys.path.append("src")
-    import i18n
-    i18n.setup_srcdir()
+sys.path.append(".")
+import src.i18n
+src.i18n.setup(".")
 
 import src
 
